#[non_exhaustive]pub enum State {
Unspecified,
Creating,
Ready,
Updating,
InUse,
Deleting,
Error,
Diagnosing,
UnknownValue(UnknownValue),
}Expand description
The Active Directory States
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified Active Directory State
Creating
Active Directory State is Creating
Ready
Active Directory State is Ready
Updating
Active Directory State is Updating
InUse
Active Directory State is In use
Deleting
Active Directory State is Deleting
Error
Active Directory State is Error
Diagnosing
Active Directory State is Diagnosing.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations