#[non_exhaustive]pub enum CacheState {
Unspecified,
PendingClusterPeering,
PendingSvmPeering,
Peered,
Error,
UnknownValue(UnknownValue),
}Expand description
State of the cache volume indicating the peering status.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default unspecified state.
PendingClusterPeering
State indicating waiting for cluster peering to be established.
PendingSvmPeering
State indicating waiting for SVM peering to be established.
Peered
State indicating successful establishment of peering with origin volumes’s ONTAP cluster.
Error
Terminal state wherein peering with origin volume’s ONTAP cluster has failed.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using CacheState::value or CacheState::name.
Implementations