#[non_exhaustive]pub enum FlexPerformance {
Unspecified,
Default,
Custom,
UnknownValue(UnknownValue),
}Expand description
Flex Storage Pool performance.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Unspecified flex performance.
Default
Flex Storage Pool with default performance.
Custom
Flex Storage Pool with custom performance.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using FlexPerformance::value or FlexPerformance::name.
Implementations