#[non_exhaustive]pub enum MirrorState {
Unspecified,
Preparing,
Mirrored,
Stopped,
Transferring,
BaselineTransferring,
Aborted,
ExternallyManaged,
PendingPeering,
UnknownValue(UnknownValue),
}Expand description
Mirroring states. No new value is expected to be added in future.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified MirrorState
Preparing
Destination volume is being prepared.
Mirrored
Destination volume has been initialized and is ready to receive replication transfers.
Stopped
Destination volume is not receiving replication transfers.
Transferring
Incremental replication is in progress.
BaselineTransferring
Baseline replication is in progress.
Aborted
Replication is aborted.
ExternallyManaged
Replication is being managed from Onprem ONTAP.
PendingPeering
Peering is yet to be established.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using MirrorState::value or MirrorState::name.
Implementations