#[non_exhaustive]pub enum State {
Unspecified,
Ready,
Creating,
Deleting,
Updating,
Restoring,
Disabled,
Error,
UnknownValue(UnknownValue),
}Expand description
The Storage Pool States
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Unspecified Storage Pool State
Ready
Storage Pool State is Ready
Creating
Storage Pool State is Creating
Deleting
Storage Pool State is Deleting
Updating
Storage Pool State is Updating
Restoring
Storage Pool State is Restoring
Disabled
Storage Pool State is Disabled
Error
Storage Pool State is Error
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations