#[non_exhaustive]pub struct ActiveDirectory {Show 22 fields
pub name: String,
pub create_time: Option<Timestamp>,
pub state: State,
pub domain: String,
pub site: String,
pub dns: String,
pub net_bios_prefix: String,
pub organizational_unit: String,
pub aes_encryption: bool,
pub username: String,
pub password: String,
pub backup_operators: Vec<String>,
pub administrators: Vec<String>,
pub security_operators: Vec<String>,
pub kdc_hostname: String,
pub kdc_ip: String,
pub nfs_users_with_ldap: bool,
pub description: String,
pub ldap_signing: bool,
pub encrypt_dc_connections: bool,
pub labels: HashMap<String, String>,
pub state_details: String,
/* private fields */
}Expand description
ActiveDirectory is the public representation of the active directory config.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the active directory.
Format:
projects/{project_number}/locations/{location_id}/activeDirectories/{active_directory_id}.
create_time: Option<Timestamp>Output only. Create time of the active directory.
state: StateOutput only. The state of the AD.
domain: StringRequired. Name of the Active Directory domain
site: StringThe Active Directory site the service will limit Domain Controller discovery too.
dns: StringRequired. Comma separated list of DNS server IP addresses for the Active Directory domain.
net_bios_prefix: StringRequired. NetBIOSPrefix is used as a prefix for SMB server name.
organizational_unit: StringThe Organizational Unit (OU) within the Windows Active Directory the user belongs to.
aes_encryption: boolIf enabled, AES encryption will be enabled for SMB communication.
username: StringRequired. Username of the Active Directory domain administrator.
password: StringRequired. Password of the Active Directory domain administrator.
backup_operators: Vec<String>Optional. Users to be added to the Built-in Backup Operator active directory group.
administrators: Vec<String>Optional. Users to be added to the Built-in Admininstrators group.
security_operators: Vec<String>Optional. Domain users to be given the SeSecurityPrivilege.
kdc_hostname: StringName of the active directory machine. This optional parameter is used only while creating kerberos volume
kdc_ip: StringKDC server IP address for the active directory machine.
nfs_users_with_ldap: boolIf enabled, will allow access to local users and LDAP users. If access is needed for only LDAP users, it has to be disabled.
description: StringDescription of the active directory.
ldap_signing: boolSpecifies whether or not the LDAP traffic needs to be signed.
encrypt_dc_connections: boolIf enabled, traffic between the SMB server to Domain Controller (DC) will be encrypted.
labels: HashMap<String, String>Labels for the active directory.
state_details: StringOutput only. The state details of the Active Directory.
Implementations
Sourceimpl ActiveDirectory
impl ActiveDirectory
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = ActiveDirectory::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = ActiveDirectory::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ActiveDirectory::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_domain<T: Into<String>>(self, v: T) -> Self
pub fn set_domain<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_net_bios_prefix<T: Into<String>>(self, v: T) -> Self
pub fn set_net_bios_prefix<T: Into<String>>(self, v: T) -> Self
Sets the value of net_bios_prefix.
Example
let x = ActiveDirectory::new().set_net_bios_prefix("example");Sourcepub fn set_organizational_unit<T: Into<String>>(self, v: T) -> Self
pub fn set_organizational_unit<T: Into<String>>(self, v: T) -> Self
Sets the value of organizational_unit.
Example
let x = ActiveDirectory::new().set_organizational_unit("example");Sourcepub fn set_aes_encryption<T: Into<bool>>(self, v: T) -> Self
pub fn set_aes_encryption<T: Into<bool>>(self, v: T) -> Self
Sets the value of aes_encryption.
Example
let x = ActiveDirectory::new().set_aes_encryption(true);Sourcepub fn set_username<T: Into<String>>(self, v: T) -> Self
pub fn set_username<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_password<T: Into<String>>(self, v: T) -> Self
pub fn set_password<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_backup_operators<T, V>(self, v: T) -> Self
pub fn set_backup_operators<T, V>(self, v: T) -> Self
Sets the value of backup_operators.
Example
let x = ActiveDirectory::new().set_backup_operators(["a", "b", "c"]);Sourcepub fn set_administrators<T, V>(self, v: T) -> Self
pub fn set_administrators<T, V>(self, v: T) -> Self
Sets the value of administrators.
Example
let x = ActiveDirectory::new().set_administrators(["a", "b", "c"]);Sourcepub fn set_security_operators<T, V>(self, v: T) -> Self
pub fn set_security_operators<T, V>(self, v: T) -> Self
Sets the value of security_operators.
Example
let x = ActiveDirectory::new().set_security_operators(["a", "b", "c"]);Sourcepub fn set_kdc_hostname<T: Into<String>>(self, v: T) -> Self
pub fn set_kdc_hostname<T: Into<String>>(self, v: T) -> Self
Sets the value of kdc_hostname.
Example
let x = ActiveDirectory::new().set_kdc_hostname("example");Sourcepub fn set_kdc_ip<T: Into<String>>(self, v: T) -> Self
pub fn set_kdc_ip<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_nfs_users_with_ldap<T: Into<bool>>(self, v: T) -> Self
pub fn set_nfs_users_with_ldap<T: Into<bool>>(self, v: T) -> Self
Sets the value of nfs_users_with_ldap.
Example
let x = ActiveDirectory::new().set_nfs_users_with_ldap(true);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_ldap_signing<T: Into<bool>>(self, v: T) -> Self
pub fn set_ldap_signing<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_encrypt_dc_connections<T: Into<bool>>(self, v: T) -> Self
pub fn set_encrypt_dc_connections<T: Into<bool>>(self, v: T) -> Self
Sets the value of encrypt_dc_connections.
Example
let x = ActiveDirectory::new().set_encrypt_dc_connections(true);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_state_details<T: Into<String>>(self, v: T) -> Self
pub fn set_state_details<T: Into<String>>(self, v: T) -> Self
Sets the value of state_details.
Example
let x = ActiveDirectory::new().set_state_details("example");Trait Implementations
Sourceimpl Clone for ActiveDirectory
impl Clone for ActiveDirectory
Sourcefn clone(&self) -> ActiveDirectory
fn clone(&self) -> ActiveDirectory
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ActiveDirectory
impl Debug for ActiveDirectory
Sourceimpl Default for ActiveDirectory
impl Default for ActiveDirectory
Sourcefn default() -> ActiveDirectory
fn default() -> ActiveDirectory
Sourceimpl Message for ActiveDirectory
impl Message for ActiveDirectory
Sourceimpl PartialEq for ActiveDirectory
impl PartialEq for ActiveDirectory
impl StructuralPartialEq for ActiveDirectory