#[non_exhaustive]pub struct Backup {Show 15 fields
pub name: String,
pub state: State,
pub description: String,
pub volume_usage_bytes: i64,
pub backup_type: Type,
pub source_volume: String,
pub source_snapshot: Option<String>,
pub create_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub chain_storage_bytes: i64,
pub satisfies_pzs: bool,
pub satisfies_pzi: bool,
pub volume_region: String,
pub backup_region: String,
pub enforced_retention_end_time: Option<Timestamp>,
/* private fields */
}Expand description
A NetApp Backup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the backup.
Format:
projects/{project_id}/locations/{location}/backupVaults/{backup_vault_id}/backups/{backup_id}.
state: StateOutput only. The backup state.
description: StringA description of the backup with 2048 characters or less. Requests with longer descriptions will be rejected.
volume_usage_bytes: i64Output only. Size of the file system when the backup was created. When creating a new volume from the backup, the volume capacity will have to be at least as big.
backup_type: TypeOutput only. Type of backup, manually created or created by a backup policy.
source_volume: StringVolume full name of this backup belongs to.
Either source_volume or ontap_source should be provided.
Format:
projects/{projects_id}/locations/{location}/volumes/{volume_id}
source_snapshot: Option<String>If specified, backup will be created from the given snapshot.
If not specified, there will be a new snapshot taken to initiate the backup
creation. Format:
projects/{project_id}/locations/{location}/volumes/{volume_id}/snapshots/{snapshot_id}
create_time: Option<Timestamp>Output only. The time when the backup was created.
labels: HashMap<String, String>Resource labels to represent user provided metadata.
chain_storage_bytes: i64Output only. Total size of all backups in a chain in bytes = baseline backup size + sum(incremental backup size)
satisfies_pzs: boolOutput only. Reserved for future use
satisfies_pzi: boolOutput only. Reserved for future use
volume_region: StringOutput only. Region of the volume from which the backup was created.
Format: projects/{project_id}/locations/{location}
backup_region: StringOutput only. Region in which backup is stored.
Format: projects/{project_id}/locations/{location}
enforced_retention_end_time: Option<Timestamp>Output only. The time until which the backup is not deletable.
Implementations
Sourceimpl Backup
impl Backup
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_volume_usage_bytes<T: Into<i64>>(self, v: T) -> Self
pub fn set_volume_usage_bytes<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_backup_type<T: Into<Type>>(self, v: T) -> Self
pub fn set_backup_type<T: Into<Type>>(self, v: T) -> Self
Sets the value of backup_type.
Example
use google_cloud_netapp_v1::model::backup::Type;
let x0 = Backup::new().set_backup_type(Type::Manual);
let x1 = Backup::new().set_backup_type(Type::Scheduled);Sourcepub fn set_source_volume<T: Into<String>>(self, v: T) -> Self
pub fn set_source_volume<T: Into<String>>(self, v: T) -> Self
Sets the value of source_volume.
Example
let x = Backup::new().set_source_volume(format!("projects/{project_id}/locations/{location_id}/volumes/{volume_id}"));Sourcepub fn set_source_snapshot<T>(self, v: T) -> Self
pub fn set_source_snapshot<T>(self, v: T) -> Self
Sets the value of source_snapshot.
Example
let x = Backup::new().set_source_snapshot(format!("projects/{project_id}/locations/{location_id}/volumes/{volume_id}/snapshots/{snapshot_id}"));Sourcepub fn set_or_clear_source_snapshot<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_source_snapshot<T>(self, v: Option<T>) -> Self
Sets or clears the value of source_snapshot.
Example
let x = Backup::new().set_or_clear_source_snapshot(Some(format!("projects/{project_id}/locations/{location_id}/volumes/{volume_id}/snapshots/{snapshot_id}")));
let x = Backup::new().set_or_clear_source_snapshot(None::<String>);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Backup::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Backup::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Backup::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_chain_storage_bytes<T: Into<i64>>(self, v: T) -> Self
pub fn set_chain_storage_bytes<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_satisfies_pzs<T: Into<bool>>(self, v: T) -> Self
pub fn set_satisfies_pzs<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_satisfies_pzi<T: Into<bool>>(self, v: T) -> Self
pub fn set_satisfies_pzi<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_volume_region<T: Into<String>>(self, v: T) -> Self
pub fn set_volume_region<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_backup_region<T: Into<String>>(self, v: T) -> Self
pub fn set_backup_region<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_enforced_retention_end_time<T>(self, v: T) -> Self
pub fn set_enforced_retention_end_time<T>(self, v: T) -> Self
Sets the value of enforced_retention_end_time.
Example
use wkt::Timestamp;
let x = Backup::new().set_enforced_retention_end_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_enforced_retention_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enforced_retention_end_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of enforced_retention_end_time.
Example
use wkt::Timestamp;
let x = Backup::new().set_or_clear_enforced_retention_end_time(Some(Timestamp::default()/* use setters */));
let x = Backup::new().set_or_clear_enforced_retention_end_time(None::<Timestamp>);Trait Implementations
impl StructuralPartialEq for Backup