#[non_exhaustive]pub struct CacheParameters {
pub peer_volume_name: String,
pub peer_cluster_name: String,
pub peer_svm_name: String,
pub peer_ip_addresses: Vec<String>,
pub enable_global_file_lock: Option<bool>,
pub cache_config: Option<CacheConfig>,
pub cache_state: CacheState,
pub command: String,
pub peering_command_expiry_time: Option<Timestamp>,
pub passphrase: String,
pub state_details: String,
/* private fields */
}Expand description
Cache Parameters for the volume.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.peer_volume_name: StringRequired. Name of the origin volume for the cache volume.
peer_cluster_name: StringRequired. Name of the origin volume’s ONTAP cluster.
peer_svm_name: StringRequired. Name of the origin volume’s SVM.
peer_ip_addresses: Vec<String>Required. List of IC LIF addresses of the origin volume’s ONTAP cluster.
enable_global_file_lock: Option<bool>Optional. Indicates whether the cache volume has global file lock enabled.
cache_config: Option<CacheConfig>Optional. Configuration of the cache volume.
cache_state: CacheStateOutput only. State of the cache volume indicating the peering status.
command: StringOutput only. Copy-paste-able commands to be used on user’s ONTAP to accept peering requests.
peering_command_expiry_time: Option<Timestamp>Optional. Expiration time for the peering command to be executed on user’s ONTAP.
passphrase: StringOutput only. Temporary passphrase generated to accept cluster peering command.
state_details: StringOutput only. Detailed description of the current cache state.
Implementations
Sourceimpl CacheParameters
impl CacheParameters
Sourcepub fn set_peer_volume_name<T: Into<String>>(self, v: T) -> Self
pub fn set_peer_volume_name<T: Into<String>>(self, v: T) -> Self
Sets the value of peer_volume_name.
Example
let x = CacheParameters::new().set_peer_volume_name("example");Sourcepub fn set_peer_cluster_name<T: Into<String>>(self, v: T) -> Self
pub fn set_peer_cluster_name<T: Into<String>>(self, v: T) -> Self
Sets the value of peer_cluster_name.
Example
let x = CacheParameters::new().set_peer_cluster_name("example");Sourcepub fn set_peer_svm_name<T: Into<String>>(self, v: T) -> Self
pub fn set_peer_svm_name<T: Into<String>>(self, v: T) -> Self
Sets the value of peer_svm_name.
Example
let x = CacheParameters::new().set_peer_svm_name("example");Sourcepub fn set_peer_ip_addresses<T, V>(self, v: T) -> Self
pub fn set_peer_ip_addresses<T, V>(self, v: T) -> Self
Sets the value of peer_ip_addresses.
Example
let x = CacheParameters::new().set_peer_ip_addresses(["a", "b", "c"]);Sourcepub fn set_enable_global_file_lock<T>(self, v: T) -> Self
pub fn set_enable_global_file_lock<T>(self, v: T) -> Self
Sets the value of enable_global_file_lock.
Example
let x = CacheParameters::new().set_enable_global_file_lock(true);Sourcepub fn set_or_clear_enable_global_file_lock<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_enable_global_file_lock<T>(self, v: Option<T>) -> Self
Sets or clears the value of enable_global_file_lock.
Example
let x = CacheParameters::new().set_or_clear_enable_global_file_lock(Some(false));
let x = CacheParameters::new().set_or_clear_enable_global_file_lock(None::<bool>);Sourcepub fn set_cache_config<T>(self, v: T) -> Selfwhere
T: Into<CacheConfig>,
pub fn set_cache_config<T>(self, v: T) -> Selfwhere
T: Into<CacheConfig>,
Sets the value of cache_config.
Example
use google_cloud_netapp_v1::model::CacheConfig;
let x = CacheParameters::new().set_cache_config(CacheConfig::default()/* use setters */);Sourcepub fn set_or_clear_cache_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<CacheConfig>,
pub fn set_or_clear_cache_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<CacheConfig>,
Sets or clears the value of cache_config.
Example
use google_cloud_netapp_v1::model::CacheConfig;
let x = CacheParameters::new().set_or_clear_cache_config(Some(CacheConfig::default()/* use setters */));
let x = CacheParameters::new().set_or_clear_cache_config(None::<CacheConfig>);Sourcepub fn set_cache_state<T: Into<CacheState>>(self, v: T) -> Self
pub fn set_cache_state<T: Into<CacheState>>(self, v: T) -> Self
Sets the value of cache_state.
Example
use google_cloud_netapp_v1::model::cache_parameters::CacheState;
let x0 = CacheParameters::new().set_cache_state(CacheState::PendingClusterPeering);
let x1 = CacheParameters::new().set_cache_state(CacheState::PendingSvmPeering);
let x2 = CacheParameters::new().set_cache_state(CacheState::Peered);Sourcepub fn set_command<T: Into<String>>(self, v: T) -> Self
pub fn set_command<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_peering_command_expiry_time<T>(self, v: T) -> Self
pub fn set_peering_command_expiry_time<T>(self, v: T) -> Self
Sets the value of peering_command_expiry_time.
Example
use wkt::Timestamp;
let x = CacheParameters::new().set_peering_command_expiry_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_peering_command_expiry_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_peering_command_expiry_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of peering_command_expiry_time.
Example
use wkt::Timestamp;
let x = CacheParameters::new().set_or_clear_peering_command_expiry_time(Some(Timestamp::default()/* use setters */));
let x = CacheParameters::new().set_or_clear_peering_command_expiry_time(None::<Timestamp>);Sourcepub fn set_passphrase<T: Into<String>>(self, v: T) -> Self
pub fn set_passphrase<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_state_details<T: Into<String>>(self, v: T) -> Self
pub fn set_state_details<T: Into<String>>(self, v: T) -> Self
Sets the value of state_details.
Example
let x = CacheParameters::new().set_state_details("example");Trait Implementations
Sourceimpl Clone for CacheParameters
impl Clone for CacheParameters
Sourcefn clone(&self) -> CacheParameters
fn clone(&self) -> CacheParameters
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CacheParameters
impl Debug for CacheParameters
Sourceimpl Default for CacheParameters
impl Default for CacheParameters
Sourcefn default() -> CacheParameters
fn default() -> CacheParameters
Sourceimpl Message for CacheParameters
impl Message for CacheParameters
Sourceimpl PartialEq for CacheParameters
impl PartialEq for CacheParameters
impl StructuralPartialEq for CacheParameters