#[non_exhaustive]pub struct CreateBackupVaultRequest {
pub parent: String,
pub backup_vault_id: String,
pub backup_vault: Option<BackupVault>,
/* private fields */
}Expand description
CreateBackupVaultRequest creates a backup vault.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The location to create the backup vaults, in the format
projects/{project_id}/locations/{location}
backup_vault_id: StringRequired. The ID to use for the backupVault. The ID must be unique within the specified location. Must contain only letters, numbers and hyphen, with the first character a letter, the last a letter or a number, and a 63 character maximum.
backup_vault: Option<BackupVault>Required. A backupVault resource
Implementations
Sourceimpl CreateBackupVaultRequest
impl CreateBackupVaultRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_backup_vault_id<T: Into<String>>(self, v: T) -> Self
pub fn set_backup_vault_id<T: Into<String>>(self, v: T) -> Self
Sets the value of backup_vault_id.
Example
ⓘ
let x = CreateBackupVaultRequest::new().set_backup_vault_id("example");Sourcepub fn set_backup_vault<T>(self, v: T) -> Selfwhere
T: Into<BackupVault>,
pub fn set_backup_vault<T>(self, v: T) -> Selfwhere
T: Into<BackupVault>,
Sets the value of backup_vault.
Example
ⓘ
use google_cloud_netapp_v1::model::BackupVault;
let x = CreateBackupVaultRequest::new().set_backup_vault(BackupVault::default()/* use setters */);Sourcepub fn set_or_clear_backup_vault<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackupVault>,
pub fn set_or_clear_backup_vault<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackupVault>,
Sets or clears the value of backup_vault.
Example
ⓘ
use google_cloud_netapp_v1::model::BackupVault;
let x = CreateBackupVaultRequest::new().set_or_clear_backup_vault(Some(BackupVault::default()/* use setters */));
let x = CreateBackupVaultRequest::new().set_or_clear_backup_vault(None::<BackupVault>);Trait Implementations
Sourceimpl Clone for CreateBackupVaultRequest
impl Clone for CreateBackupVaultRequest
Sourcefn clone(&self) -> CreateBackupVaultRequest
fn clone(&self) -> CreateBackupVaultRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateBackupVaultRequest
impl Debug for CreateBackupVaultRequest
Sourceimpl Default for CreateBackupVaultRequest
impl Default for CreateBackupVaultRequest
Sourcefn default() -> CreateBackupVaultRequest
fn default() -> CreateBackupVaultRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateBackupVaultRequest
impl Message for CreateBackupVaultRequest
Sourceimpl PartialEq for CreateBackupVaultRequest
impl PartialEq for CreateBackupVaultRequest
impl StructuralPartialEq for CreateBackupVaultRequest