#[non_exhaustive]pub struct CreateHostGroupRequest {
pub parent: String,
pub host_group: Option<HostGroup>,
pub host_group_id: String,
/* private fields */
}Expand description
CreateHostGroupRequest for creating a host group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Parent value for CreateHostGroupRequest
host_group: Option<HostGroup>Required. Fields of the host group to create.
host_group_id: StringRequired. ID of the host group to create. Must be unique within the parent resource. Must contain only letters, numbers, and hyphen, with the first character a letter or underscore, the last a letter or underscore or a number, and a 63 character maximum.
Implementations
Sourceimpl CreateHostGroupRequest
impl CreateHostGroupRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_host_group<T>(self, v: T) -> Self
pub fn set_host_group<T>(self, v: T) -> Self
Sets the value of host_group.
Example
ⓘ
use google_cloud_netapp_v1::model::HostGroup;
let x = CreateHostGroupRequest::new().set_host_group(HostGroup::default()/* use setters */);Sourcepub fn set_or_clear_host_group<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_host_group<T>(self, v: Option<T>) -> Self
Sets or clears the value of host_group.
Example
ⓘ
use google_cloud_netapp_v1::model::HostGroup;
let x = CreateHostGroupRequest::new().set_or_clear_host_group(Some(HostGroup::default()/* use setters */));
let x = CreateHostGroupRequest::new().set_or_clear_host_group(None::<HostGroup>);Sourcepub fn set_host_group_id<T: Into<String>>(self, v: T) -> Self
pub fn set_host_group_id<T: Into<String>>(self, v: T) -> Self
Sets the value of host_group_id.
Example
ⓘ
let x = CreateHostGroupRequest::new().set_host_group_id("example");Trait Implementations
Sourceimpl Clone for CreateHostGroupRequest
impl Clone for CreateHostGroupRequest
Sourcefn clone(&self) -> CreateHostGroupRequest
fn clone(&self) -> CreateHostGroupRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateHostGroupRequest
impl Debug for CreateHostGroupRequest
Sourceimpl Default for CreateHostGroupRequest
impl Default for CreateHostGroupRequest
Sourcefn default() -> CreateHostGroupRequest
fn default() -> CreateHostGroupRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateHostGroupRequest
impl Message for CreateHostGroupRequest
Sourceimpl PartialEq for CreateHostGroupRequest
impl PartialEq for CreateHostGroupRequest
impl StructuralPartialEq for CreateHostGroupRequest