#[non_exhaustive]pub struct CreateQuotaRuleRequest {
pub parent: String,
pub quota_rule: Option<QuotaRule>,
pub quota_rule_id: String,
/* private fields */
}Expand description
CreateQuotaRuleRequest for creating a quota rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Parent value for CreateQuotaRuleRequest
quota_rule: Option<QuotaRule>Required. Fields of the to be created quota rule.
quota_rule_id: StringRequired. ID of the quota rule to create. Must be unique within the parent resource. Must contain only letters, numbers, underscore and hyphen, with the first character a letter or underscore, the last a letter or underscore or a number, and a 63 character maximum.
Implementations
Sourceimpl CreateQuotaRuleRequest
impl CreateQuotaRuleRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_quota_rule<T>(self, v: T) -> Self
pub fn set_quota_rule<T>(self, v: T) -> Self
Sets the value of quota_rule.
Example
ⓘ
use google_cloud_netapp_v1::model::QuotaRule;
let x = CreateQuotaRuleRequest::new().set_quota_rule(QuotaRule::default()/* use setters */);Sourcepub fn set_or_clear_quota_rule<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_quota_rule<T>(self, v: Option<T>) -> Self
Sets or clears the value of quota_rule.
Example
ⓘ
use google_cloud_netapp_v1::model::QuotaRule;
let x = CreateQuotaRuleRequest::new().set_or_clear_quota_rule(Some(QuotaRule::default()/* use setters */));
let x = CreateQuotaRuleRequest::new().set_or_clear_quota_rule(None::<QuotaRule>);Sourcepub fn set_quota_rule_id<T: Into<String>>(self, v: T) -> Self
pub fn set_quota_rule_id<T: Into<String>>(self, v: T) -> Self
Sets the value of quota_rule_id.
Example
ⓘ
let x = CreateQuotaRuleRequest::new().set_quota_rule_id("example");Trait Implementations
Sourceimpl Clone for CreateQuotaRuleRequest
impl Clone for CreateQuotaRuleRequest
Sourcefn clone(&self) -> CreateQuotaRuleRequest
fn clone(&self) -> CreateQuotaRuleRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateQuotaRuleRequest
impl Debug for CreateQuotaRuleRequest
Sourceimpl Default for CreateQuotaRuleRequest
impl Default for CreateQuotaRuleRequest
Sourcefn default() -> CreateQuotaRuleRequest
fn default() -> CreateQuotaRuleRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateQuotaRuleRequest
impl Message for CreateQuotaRuleRequest
Sourceimpl PartialEq for CreateQuotaRuleRequest
impl PartialEq for CreateQuotaRuleRequest
impl StructuralPartialEq for CreateQuotaRuleRequest