#[non_exhaustive]pub struct CreateSnapshotRequest {
pub parent: String,
pub snapshot: Option<Snapshot>,
pub snapshot_id: String,
/* private fields */
}Expand description
CreateSnapshotRequest creates a snapshot.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The NetApp volume to create the snapshots of, in the format
projects/{project_id}/locations/{location}/volumes/{volume_id}
snapshot: Option<Snapshot>Required. A snapshot resource
snapshot_id: StringRequired. ID of the snapshot to create. Must be unique within the parent resource. Must contain only letters, numbers and hyphen, with the first character a letter, the last a letter or a number, and a 63 character maximum.
Implementations
Sourceimpl CreateSnapshotRequest
impl CreateSnapshotRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_snapshot<T>(self, v: T) -> Self
pub fn set_snapshot<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_snapshot<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_snapshot<T>(self, v: Option<T>) -> Self
Sourcepub fn set_snapshot_id<T: Into<String>>(self, v: T) -> Self
pub fn set_snapshot_id<T: Into<String>>(self, v: T) -> Self
Sets the value of snapshot_id.
Example
ⓘ
let x = CreateSnapshotRequest::new().set_snapshot_id("example");Trait Implementations
Sourceimpl Clone for CreateSnapshotRequest
impl Clone for CreateSnapshotRequest
Sourcefn clone(&self) -> CreateSnapshotRequest
fn clone(&self) -> CreateSnapshotRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateSnapshotRequest
impl Debug for CreateSnapshotRequest
Sourceimpl Default for CreateSnapshotRequest
impl Default for CreateSnapshotRequest
Sourcefn default() -> CreateSnapshotRequest
fn default() -> CreateSnapshotRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateSnapshotRequest
impl Message for CreateSnapshotRequest
Sourceimpl PartialEq for CreateSnapshotRequest
impl PartialEq for CreateSnapshotRequest
impl StructuralPartialEq for CreateSnapshotRequest