#[non_exhaustive]pub struct DestinationVolumeParameters {
pub storage_pool: String,
pub volume_id: String,
pub share_name: String,
pub description: Option<String>,
pub tiering_policy: Option<TieringPolicy>,
/* private fields */
}Expand description
DestinationVolumeParameters specify input parameters used for creating destination volume.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.storage_pool: StringRequired. Existing destination StoragePool name.
volume_id: StringDesired destination volume resource id. If not specified, source volume’s resource id will be used. This value must start with a lowercase letter followed by up to 62 lowercase letters, numbers, or hyphens, and cannot end with a hyphen.
Destination volume’s share name. If not specified, source volume’s share name will be used.
description: Option<String>Description for the destination volume.
tiering_policy: Option<TieringPolicy>Optional. Tiering policy for the volume.
Implementations
Sourceimpl DestinationVolumeParameters
impl DestinationVolumeParameters
Sourcepub fn set_storage_pool<T: Into<String>>(self, v: T) -> Self
pub fn set_storage_pool<T: Into<String>>(self, v: T) -> Self
Sets the value of storage_pool.
Example
let x = DestinationVolumeParameters::new().set_storage_pool(format!("projects/{project_id}/locations/{location_id}/storagePools/{storage_pool_id}"));Sourcepub fn set_volume_id<T: Into<String>>(self, v: T) -> Self
pub fn set_volume_id<T: Into<String>>(self, v: T) -> Self
Sets the value of share_name.
Example
let x = DestinationVolumeParameters::new().set_share_name("example");Sourcepub fn set_description<T>(self, v: T) -> Self
pub fn set_description<T>(self, v: T) -> Self
Sets the value of description.
Example
let x = DestinationVolumeParameters::new().set_description("example");Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Self
Sets or clears the value of description.
Example
let x = DestinationVolumeParameters::new().set_or_clear_description(Some("example"));
let x = DestinationVolumeParameters::new().set_or_clear_description(None::<String>);Sourcepub fn set_tiering_policy<T>(self, v: T) -> Selfwhere
T: Into<TieringPolicy>,
pub fn set_tiering_policy<T>(self, v: T) -> Selfwhere
T: Into<TieringPolicy>,
Sets the value of tiering_policy.
Example
use google_cloud_netapp_v1::model::TieringPolicy;
let x = DestinationVolumeParameters::new().set_tiering_policy(TieringPolicy::default()/* use setters */);Sourcepub fn set_or_clear_tiering_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<TieringPolicy>,
pub fn set_or_clear_tiering_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<TieringPolicy>,
Sets or clears the value of tiering_policy.
Example
use google_cloud_netapp_v1::model::TieringPolicy;
let x = DestinationVolumeParameters::new().set_or_clear_tiering_policy(Some(TieringPolicy::default()/* use setters */));
let x = DestinationVolumeParameters::new().set_or_clear_tiering_policy(None::<TieringPolicy>);Trait Implementations
Sourceimpl Clone for DestinationVolumeParameters
impl Clone for DestinationVolumeParameters
Sourcefn clone(&self) -> DestinationVolumeParameters
fn clone(&self) -> DestinationVolumeParameters
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DestinationVolumeParameters
impl Debug for DestinationVolumeParameters
Sourceimpl Default for DestinationVolumeParameters
impl Default for DestinationVolumeParameters
Sourcefn default() -> DestinationVolumeParameters
fn default() -> DestinationVolumeParameters
impl StructuralPartialEq for DestinationVolumeParameters