#[non_exhaustive]pub struct HourlySchedule {
pub snapshots_to_keep: Option<f64>,
pub minute: Option<f64>,
/* private fields */
}Expand description
Make a snapshot every hour e.g. at 04:00, 05:00, 06:00.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.snapshots_to_keep: Option<f64>The maximum number of Snapshots to keep for the hourly schedule
minute: Option<f64>Set the minute of the hour to start the snapshot (0-59), defaults to the top of the hour (0).
Implementations
Sourceimpl HourlySchedule
impl HourlySchedule
pub fn new() -> Self
Sourcepub fn set_snapshots_to_keep<T>(self, v: T) -> Self
pub fn set_snapshots_to_keep<T>(self, v: T) -> Self
Sets the value of snapshots_to_keep.
Example
ⓘ
let x = HourlySchedule::new().set_snapshots_to_keep(42.0);Sourcepub fn set_or_clear_snapshots_to_keep<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_snapshots_to_keep<T>(self, v: Option<T>) -> Self
Sets or clears the value of snapshots_to_keep.
Example
ⓘ
let x = HourlySchedule::new().set_or_clear_snapshots_to_keep(Some(42.0));
let x = HourlySchedule::new().set_or_clear_snapshots_to_keep(None::<f32>);Sourcepub fn set_minute<T>(self, v: T) -> Self
pub fn set_minute<T>(self, v: T) -> Self