#[non_exhaustive]pub struct LargeCapacityConfig {
pub constituent_count: i32,
/* private fields */
}Expand description
Configuration for a Large Capacity Volume. A Large Capacity Volume supports sizes ranging from 4.8 TiB to 20 PiB, it is composed of multiple internal constituents, and must be created in a large capacity pool.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.constituent_count: i32Optional. The number of internal constituents (e.g., FlexVols) for this large volume. The minimum number of constituents is 2.
Implementations
Sourceimpl LargeCapacityConfig
impl LargeCapacityConfig
Sourcepub fn set_constituent_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_constituent_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of constituent_count.
Example
ⓘ
let x = LargeCapacityConfig::new().set_constituent_count(42);Trait Implementations
Sourceimpl Clone for LargeCapacityConfig
impl Clone for LargeCapacityConfig
Sourcefn clone(&self) -> LargeCapacityConfig
fn clone(&self) -> LargeCapacityConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LargeCapacityConfig
impl Debug for LargeCapacityConfig
Sourceimpl Default for LargeCapacityConfig
impl Default for LargeCapacityConfig
Sourcefn default() -> LargeCapacityConfig
fn default() -> LargeCapacityConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for LargeCapacityConfig
impl Message for LargeCapacityConfig
Sourceimpl PartialEq for LargeCapacityConfig
impl PartialEq for LargeCapacityConfig
impl StructuralPartialEq for LargeCapacityConfig