#[non_exhaustive]pub struct ListBackupVaultsResponse {
pub backup_vaults: Vec<BackupVault>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
ListBackupVaultsResponse is the result of ListBackupVaultsRequest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backup_vaults: Vec<BackupVault>A list of backupVaults in the project for the specified location.
next_page_token: StringThe token you can use to retrieve the next page of results. Not returned if there are no more results in the list.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListBackupVaultsResponse
impl ListBackupVaultsResponse
Sourcepub fn set_backup_vaults<T, V>(self, v: T) -> Self
pub fn set_backup_vaults<T, V>(self, v: T) -> Self
Sets the value of backup_vaults.
Example
ⓘ
use google_cloud_netapp_v1::model::BackupVault;
let x = ListBackupVaultsResponse::new()
.set_backup_vaults([
BackupVault::default()/* use setters */,
BackupVault::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListBackupVaultsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListBackupVaultsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListBackupVaultsResponse
impl Clone for ListBackupVaultsResponse
Sourcefn clone(&self) -> ListBackupVaultsResponse
fn clone(&self) -> ListBackupVaultsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListBackupVaultsResponse
impl Debug for ListBackupVaultsResponse
Sourceimpl Default for ListBackupVaultsResponse
impl Default for ListBackupVaultsResponse
Sourcefn default() -> ListBackupVaultsResponse
fn default() -> ListBackupVaultsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListBackupVaultsResponse
impl Message for ListBackupVaultsResponse
Sourceimpl PartialEq for ListBackupVaultsResponse
impl PartialEq for ListBackupVaultsResponse
impl StructuralPartialEq for ListBackupVaultsResponse