ListBackupsRequest

Struct ListBackupsRequest 

#[non_exhaustive]
pub struct ListBackupsRequest { pub parent: String, pub page_size: i32, pub page_token: String, pub order_by: String, pub filter: String, /* private fields */ }
ListBackupsRequest lists backups.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The backupVault for which to retrieve backup information, in the format projects/{project_id}/locations/{location}/backupVaults/{backup_vault_id}. To retrieve backup information for all locations, use “-” for the {location} value. To retrieve backup information for all backupVaults, use “-” for the {backup_vault_id} value. To retrieve backup information for a volume, use “-” for the {backup_vault_id} value and specify volume full name with the filter.

page_size: i32

The maximum number of items to return. The service may return fewer than this value. The maximum value is 1000; values above 1000 will be coerced to 1000.

page_token: String

The next_page_token value to use if there are additional results to retrieve for this list request.

order_by: String

Sort results. Supported values are “name”, “name desc” or “” (unsorted).

filter: String

The standard list filter. If specified, backups will be returned based on the attribute name that matches the filter expression. If empty, then no backups are filtered out. See https://google.aip.dev/160

Implementations

Source

impl ListBackupsRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListBackupsRequest::new().set_parent(format!("projects/{project_id}/locations/{location_id}/backupVaults/{backup_vault_id}"));
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListBackupsRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListBackupsRequest::new().set_page_token("example");
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self

Sets the value of order_by.

Example
let x = ListBackupsRequest::new().set_order_by("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListBackupsRequest::new().set_filter("example");