#[non_exhaustive]pub struct ListReplicationsResponse {
pub replications: Vec<Replication>,
pub next_page_token: String,
pub unreachable: Vec<String>,
/* private fields */
}Expand description
ListReplicationsResponse is the result of ListReplicationsRequest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.replications: Vec<Replication>A list of replications in the project for the specified volume.
next_page_token: StringThe token you can use to retrieve the next page of results. Not returned if there are no more results in the list.
unreachable: Vec<String>Locations that could not be reached.
Implementations
Sourceimpl ListReplicationsResponse
impl ListReplicationsResponse
Sourcepub fn set_replications<T, V>(self, v: T) -> Self
pub fn set_replications<T, V>(self, v: T) -> Self
Sets the value of replications.
Example
ⓘ
use google_cloud_netapp_v1::model::Replication;
let x = ListReplicationsResponse::new()
.set_replications([
Replication::default()/* use setters */,
Replication::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListReplicationsResponse::new().set_next_page_token("example");Sourcepub fn set_unreachable<T, V>(self, v: T) -> Self
pub fn set_unreachable<T, V>(self, v: T) -> Self
Sets the value of unreachable.
Example
ⓘ
let x = ListReplicationsResponse::new().set_unreachable(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ListReplicationsResponse
impl Clone for ListReplicationsResponse
Sourcefn clone(&self) -> ListReplicationsResponse
fn clone(&self) -> ListReplicationsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListReplicationsResponse
impl Debug for ListReplicationsResponse
Sourceimpl Default for ListReplicationsResponse
impl Default for ListReplicationsResponse
Sourcefn default() -> ListReplicationsResponse
fn default() -> ListReplicationsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListReplicationsResponse
impl Message for ListReplicationsResponse
Sourceimpl PartialEq for ListReplicationsResponse
impl PartialEq for ListReplicationsResponse
impl StructuralPartialEq for ListReplicationsResponse