#[non_exhaustive]pub struct RevertVolumeRequest {
pub name: String,
pub snapshot_id: String,
/* private fields */
}Expand description
RevertVolumeRequest reverts the given volume to the specified snapshot.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the volume, in the format of projects/{project_id}/locations/{location}/volumes/{volume_id}.
snapshot_id: StringRequired. The snapshot resource ID, in the format ‘my-snapshot’, where the specified ID is the {snapshot_id} of the fully qualified name like projects/{project_id}/locations/{location_id}/volumes/{volume_id}/snapshots/{snapshot_id}
Implementations
Sourceimpl RevertVolumeRequest
impl RevertVolumeRequest