#[non_exhaustive]pub struct TieringPolicy {
pub tier_action: Option<TierAction>,
pub cooling_threshold_days: Option<i32>,
pub hot_tier_bypass_mode_enabled: Option<bool>,
/* private fields */
}Expand description
Defines tiering policy for the volume.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tier_action: Option<TierAction>Optional. Flag indicating if the volume has tiering policy enable/pause. Default is PAUSED.
cooling_threshold_days: Option<i32>Optional. Time in days to mark the volume’s data block as cold and make it eligible for tiering, can be range from 2-183. Default is 31.
hot_tier_bypass_mode_enabled: Option<bool>Optional. Flag indicating that the hot tier bypass mode is enabled. Default is false. This is only applicable to Flex service level.
Implementations
Sourceimpl TieringPolicy
impl TieringPolicy
pub fn new() -> Self
Sourcepub fn set_tier_action<T>(self, v: T) -> Selfwhere
T: Into<TierAction>,
pub fn set_tier_action<T>(self, v: T) -> Selfwhere
T: Into<TierAction>,
Sets the value of tier_action.
Example
ⓘ
use google_cloud_netapp_v1::model::tiering_policy::TierAction;
let x0 = TieringPolicy::new().set_tier_action(TierAction::Enabled);
let x1 = TieringPolicy::new().set_tier_action(TierAction::Paused);Sourcepub fn set_or_clear_tier_action<T>(self, v: Option<T>) -> Selfwhere
T: Into<TierAction>,
pub fn set_or_clear_tier_action<T>(self, v: Option<T>) -> Selfwhere
T: Into<TierAction>,
Sets or clears the value of tier_action.
Example
ⓘ
use google_cloud_netapp_v1::model::tiering_policy::TierAction;
let x0 = TieringPolicy::new().set_or_clear_tier_action(Some(TierAction::Enabled));
let x1 = TieringPolicy::new().set_or_clear_tier_action(Some(TierAction::Paused));
let x_none = TieringPolicy::new().set_or_clear_tier_action(None::<TierAction>);Sourcepub fn set_cooling_threshold_days<T>(self, v: T) -> Self
pub fn set_cooling_threshold_days<T>(self, v: T) -> Self
Sets the value of cooling_threshold_days.
Example
ⓘ
let x = TieringPolicy::new().set_cooling_threshold_days(42);Sourcepub fn set_or_clear_cooling_threshold_days<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cooling_threshold_days<T>(self, v: Option<T>) -> Self
Sets or clears the value of cooling_threshold_days.
Example
ⓘ
let x = TieringPolicy::new().set_or_clear_cooling_threshold_days(Some(42));
let x = TieringPolicy::new().set_or_clear_cooling_threshold_days(None::<i32>);Sourcepub fn set_hot_tier_bypass_mode_enabled<T>(self, v: T) -> Self
pub fn set_hot_tier_bypass_mode_enabled<T>(self, v: T) -> Self
Sets the value of hot_tier_bypass_mode_enabled.
Example
ⓘ
let x = TieringPolicy::new().set_hot_tier_bypass_mode_enabled(true);Sourcepub fn set_or_clear_hot_tier_bypass_mode_enabled<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_hot_tier_bypass_mode_enabled<T>(self, v: Option<T>) -> Self
Sets or clears the value of hot_tier_bypass_mode_enabled.
Example
ⓘ
let x = TieringPolicy::new().set_or_clear_hot_tier_bypass_mode_enabled(Some(false));
let x = TieringPolicy::new().set_or_clear_hot_tier_bypass_mode_enabled(None::<bool>);Trait Implementations
Sourceimpl Clone for TieringPolicy
impl Clone for TieringPolicy
Sourcefn clone(&self) -> TieringPolicy
fn clone(&self) -> TieringPolicy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TieringPolicy
impl Debug for TieringPolicy
Sourceimpl Default for TieringPolicy
impl Default for TieringPolicy
Sourcefn default() -> TieringPolicy
fn default() -> TieringPolicy
Returns the “default value” for a type. Read more
Sourceimpl Message for TieringPolicy
impl Message for TieringPolicy
Sourceimpl PartialEq for TieringPolicy
impl PartialEq for TieringPolicy
impl StructuralPartialEq for TieringPolicy