#[non_exhaustive]pub struct TransferStats {
pub transfer_bytes: Option<i64>,
pub total_transfer_duration: Option<Duration>,
pub last_transfer_bytes: Option<i64>,
pub last_transfer_duration: Option<Duration>,
pub lag_duration: Option<Duration>,
pub update_time: Option<Timestamp>,
pub last_transfer_end_time: Option<Timestamp>,
pub last_transfer_error: Option<String>,
/* private fields */
}Expand description
TransferStats reports all statistics related to replication transfer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.transfer_bytes: Option<i64>Cumulative bytes transferred so far for the replication relationship.
total_transfer_duration: Option<Duration>Cumulative time taken across all transfers for the replication relationship.
last_transfer_bytes: Option<i64>Last transfer size in bytes.
last_transfer_duration: Option<Duration>Time taken during last transfer.
lag_duration: Option<Duration>Lag duration indicates the duration by which Destination region volume content lags behind the primary region volume content.
update_time: Option<Timestamp>Time when progress was updated last.
last_transfer_end_time: Option<Timestamp>Time when last transfer completed.
last_transfer_error: Option<String>A message describing the cause of the last transfer failure.
Implementations
Sourceimpl TransferStats
impl TransferStats
Sourcepub fn set_transfer_bytes<T>(self, v: T) -> Self
pub fn set_transfer_bytes<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_transfer_bytes<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_transfer_bytes<T>(self, v: Option<T>) -> Self
Sets or clears the value of transfer_bytes.
Example
let x = TransferStats::new().set_or_clear_transfer_bytes(Some(42));
let x = TransferStats::new().set_or_clear_transfer_bytes(None::<i32>);Sourcepub fn set_total_transfer_duration<T>(self, v: T) -> Self
pub fn set_total_transfer_duration<T>(self, v: T) -> Self
Sets the value of total_transfer_duration.
Example
use wkt::Duration;
let x = TransferStats::new().set_total_transfer_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_total_transfer_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_total_transfer_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of total_transfer_duration.
Example
use wkt::Duration;
let x = TransferStats::new().set_or_clear_total_transfer_duration(Some(Duration::default()/* use setters */));
let x = TransferStats::new().set_or_clear_total_transfer_duration(None::<Duration>);Sourcepub fn set_last_transfer_bytes<T>(self, v: T) -> Self
pub fn set_last_transfer_bytes<T>(self, v: T) -> Self
Sets the value of last_transfer_bytes.
Example
let x = TransferStats::new().set_last_transfer_bytes(42);Sourcepub fn set_or_clear_last_transfer_bytes<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_transfer_bytes<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_transfer_bytes.
Example
let x = TransferStats::new().set_or_clear_last_transfer_bytes(Some(42));
let x = TransferStats::new().set_or_clear_last_transfer_bytes(None::<i32>);Sourcepub fn set_last_transfer_duration<T>(self, v: T) -> Self
pub fn set_last_transfer_duration<T>(self, v: T) -> Self
Sets the value of last_transfer_duration.
Example
use wkt::Duration;
let x = TransferStats::new().set_last_transfer_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_last_transfer_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_transfer_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_transfer_duration.
Example
use wkt::Duration;
let x = TransferStats::new().set_or_clear_last_transfer_duration(Some(Duration::default()/* use setters */));
let x = TransferStats::new().set_or_clear_last_transfer_duration(None::<Duration>);Sourcepub fn set_lag_duration<T>(self, v: T) -> Self
pub fn set_lag_duration<T>(self, v: T) -> Self
Sets the value of lag_duration.
Example
use wkt::Duration;
let x = TransferStats::new().set_lag_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_lag_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_lag_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of lag_duration.
Example
use wkt::Duration;
let x = TransferStats::new().set_or_clear_lag_duration(Some(Duration::default()/* use setters */));
let x = TransferStats::new().set_or_clear_lag_duration(None::<Duration>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = TransferStats::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = TransferStats::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = TransferStats::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_last_transfer_end_time<T>(self, v: T) -> Self
pub fn set_last_transfer_end_time<T>(self, v: T) -> Self
Sets the value of last_transfer_end_time.
Example
use wkt::Timestamp;
let x = TransferStats::new().set_last_transfer_end_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_transfer_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_transfer_end_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_transfer_end_time.
Example
use wkt::Timestamp;
let x = TransferStats::new().set_or_clear_last_transfer_end_time(Some(Timestamp::default()/* use setters */));
let x = TransferStats::new().set_or_clear_last_transfer_end_time(None::<Timestamp>);Sourcepub fn set_last_transfer_error<T>(self, v: T) -> Self
pub fn set_last_transfer_error<T>(self, v: T) -> Self
Sets the value of last_transfer_error.
Example
let x = TransferStats::new().set_last_transfer_error("example");Sourcepub fn set_or_clear_last_transfer_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_transfer_error<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_transfer_error.
Example
let x = TransferStats::new().set_or_clear_last_transfer_error(Some("example"));
let x = TransferStats::new().set_or_clear_last_transfer_error(None::<String>);Trait Implementations
Sourceimpl Clone for TransferStats
impl Clone for TransferStats
Sourcefn clone(&self) -> TransferStats
fn clone(&self) -> TransferStats
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TransferStats
impl Debug for TransferStats
Sourceimpl Default for TransferStats
impl Default for TransferStats
Sourcefn default() -> TransferStats
fn default() -> TransferStats
Sourceimpl Message for TransferStats
impl Message for TransferStats
Sourceimpl PartialEq for TransferStats
impl PartialEq for TransferStats
impl StructuralPartialEq for TransferStats