#[non_exhaustive]pub struct UpdateActiveDirectoryRequest {
pub update_mask: Option<FieldMask>,
pub active_directory: Option<ActiveDirectory>,
/* private fields */
}Expand description
UpdateActiveDirectoryRequest for updating an active directory.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Field mask is used to specify the fields to be overwritten in the Active Directory resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
active_directory: Option<ActiveDirectory>Required. The volume being updated
Implementations
Sourceimpl UpdateActiveDirectoryRequest
impl UpdateActiveDirectoryRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateActiveDirectoryRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateActiveDirectoryRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateActiveDirectoryRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_active_directory<T>(self, v: T) -> Selfwhere
T: Into<ActiveDirectory>,
pub fn set_active_directory<T>(self, v: T) -> Selfwhere
T: Into<ActiveDirectory>,
Sets the value of active_directory.
Example
ⓘ
use google_cloud_netapp_v1::model::ActiveDirectory;
let x = UpdateActiveDirectoryRequest::new().set_active_directory(ActiveDirectory::default()/* use setters */);Sourcepub fn set_or_clear_active_directory<T>(self, v: Option<T>) -> Selfwhere
T: Into<ActiveDirectory>,
pub fn set_or_clear_active_directory<T>(self, v: Option<T>) -> Selfwhere
T: Into<ActiveDirectory>,
Sets or clears the value of active_directory.
Example
ⓘ
use google_cloud_netapp_v1::model::ActiveDirectory;
let x = UpdateActiveDirectoryRequest::new().set_or_clear_active_directory(Some(ActiveDirectory::default()/* use setters */));
let x = UpdateActiveDirectoryRequest::new().set_or_clear_active_directory(None::<ActiveDirectory>);Trait Implementations
Sourceimpl Clone for UpdateActiveDirectoryRequest
impl Clone for UpdateActiveDirectoryRequest
Sourcefn clone(&self) -> UpdateActiveDirectoryRequest
fn clone(&self) -> UpdateActiveDirectoryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateActiveDirectoryRequest
impl Debug for UpdateActiveDirectoryRequest
Sourceimpl Default for UpdateActiveDirectoryRequest
impl Default for UpdateActiveDirectoryRequest
Sourcefn default() -> UpdateActiveDirectoryRequest
fn default() -> UpdateActiveDirectoryRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for UpdateActiveDirectoryRequest