#[non_exhaustive]pub struct UpdateBackupRequest {
pub update_mask: Option<FieldMask>,
pub backup: Option<Backup>,
/* private fields */
}Expand description
UpdateBackupRequest updates description and/or labels for a backup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Field mask is used to specify the fields to be overwritten in the Backup resource to be updated. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
backup: Option<Backup>Required. The backup being updated
Implementations
Sourceimpl UpdateBackupRequest
impl UpdateBackupRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateBackupRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateBackupRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateBackupRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_backup<T>(self, v: T) -> Self
pub fn set_backup<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_backup<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_backup<T>(self, v: Option<T>) -> Self