#[non_exhaustive]pub struct UpdateBackupVaultRequest {
pub update_mask: Option<FieldMask>,
pub backup_vault: Option<BackupVault>,
/* private fields */
}Expand description
UpdateBackupVaultRequest updates description and/or labels for a backupVault.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Field mask is used to specify the fields to be overwritten in the Backup resource to be updated. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
backup_vault: Option<BackupVault>Required. The backupVault being updated
Implementations
Sourceimpl UpdateBackupVaultRequest
impl UpdateBackupVaultRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateBackupVaultRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateBackupVaultRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateBackupVaultRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_backup_vault<T>(self, v: T) -> Selfwhere
T: Into<BackupVault>,
pub fn set_backup_vault<T>(self, v: T) -> Selfwhere
T: Into<BackupVault>,
Sets the value of backup_vault.
Example
ⓘ
use google_cloud_netapp_v1::model::BackupVault;
let x = UpdateBackupVaultRequest::new().set_backup_vault(BackupVault::default()/* use setters */);Sourcepub fn set_or_clear_backup_vault<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackupVault>,
pub fn set_or_clear_backup_vault<T>(self, v: Option<T>) -> Selfwhere
T: Into<BackupVault>,
Sets or clears the value of backup_vault.
Example
ⓘ
use google_cloud_netapp_v1::model::BackupVault;
let x = UpdateBackupVaultRequest::new().set_or_clear_backup_vault(Some(BackupVault::default()/* use setters */));
let x = UpdateBackupVaultRequest::new().set_or_clear_backup_vault(None::<BackupVault>);Trait Implementations
Sourceimpl Clone for UpdateBackupVaultRequest
impl Clone for UpdateBackupVaultRequest
Sourcefn clone(&self) -> UpdateBackupVaultRequest
fn clone(&self) -> UpdateBackupVaultRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateBackupVaultRequest
impl Debug for UpdateBackupVaultRequest
Sourceimpl Default for UpdateBackupVaultRequest
impl Default for UpdateBackupVaultRequest
Sourcefn default() -> UpdateBackupVaultRequest
fn default() -> UpdateBackupVaultRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateBackupVaultRequest
impl Message for UpdateBackupVaultRequest
Sourceimpl PartialEq for UpdateBackupVaultRequest
impl PartialEq for UpdateBackupVaultRequest
impl StructuralPartialEq for UpdateBackupVaultRequest