#[non_exhaustive]pub struct UpdateKmsConfigRequest {
pub update_mask: Option<FieldMask>,
pub kms_config: Option<KmsConfig>,
/* private fields */
}Expand description
UpdateKmsConfigRequest updates a KMS Config.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Field mask is used to specify the fields to be overwritten in the KmsConfig resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
kms_config: Option<KmsConfig>Required. The KmsConfig being updated
Implementations
Sourceimpl UpdateKmsConfigRequest
impl UpdateKmsConfigRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateKmsConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateKmsConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateKmsConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_kms_config<T>(self, v: T) -> Self
pub fn set_kms_config<T>(self, v: T) -> Self
Sets the value of kms_config.
Example
ⓘ
use google_cloud_netapp_v1::model::KmsConfig;
let x = UpdateKmsConfigRequest::new().set_kms_config(KmsConfig::default()/* use setters */);Sourcepub fn set_or_clear_kms_config<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kms_config<T>(self, v: Option<T>) -> Self
Sets or clears the value of kms_config.
Example
ⓘ
use google_cloud_netapp_v1::model::KmsConfig;
let x = UpdateKmsConfigRequest::new().set_or_clear_kms_config(Some(KmsConfig::default()/* use setters */));
let x = UpdateKmsConfigRequest::new().set_or_clear_kms_config(None::<KmsConfig>);Trait Implementations
Sourceimpl Clone for UpdateKmsConfigRequest
impl Clone for UpdateKmsConfigRequest
Sourcefn clone(&self) -> UpdateKmsConfigRequest
fn clone(&self) -> UpdateKmsConfigRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateKmsConfigRequest
impl Debug for UpdateKmsConfigRequest
Sourceimpl Default for UpdateKmsConfigRequest
impl Default for UpdateKmsConfigRequest
Sourcefn default() -> UpdateKmsConfigRequest
fn default() -> UpdateKmsConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateKmsConfigRequest
impl Message for UpdateKmsConfigRequest
Sourceimpl PartialEq for UpdateKmsConfigRequest
impl PartialEq for UpdateKmsConfigRequest
impl StructuralPartialEq for UpdateKmsConfigRequest