#[non_exhaustive]pub struct UpdateQuotaRuleRequest {
pub update_mask: Option<FieldMask>,
pub quota_rule: Option<QuotaRule>,
/* private fields */
}Expand description
UpdateQuotaRuleRequest for updating a quota rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. Field mask is used to specify the fields to be overwritten in the Quota Rule resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
quota_rule: Option<QuotaRule>Required. The quota rule being updated
Implementations
Sourceimpl UpdateQuotaRuleRequest
impl UpdateQuotaRuleRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateQuotaRuleRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateQuotaRuleRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateQuotaRuleRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_quota_rule<T>(self, v: T) -> Self
pub fn set_quota_rule<T>(self, v: T) -> Self
Sets the value of quota_rule.
Example
ⓘ
use google_cloud_netapp_v1::model::QuotaRule;
let x = UpdateQuotaRuleRequest::new().set_quota_rule(QuotaRule::default()/* use setters */);Sourcepub fn set_or_clear_quota_rule<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_quota_rule<T>(self, v: Option<T>) -> Self
Sets or clears the value of quota_rule.
Example
ⓘ
use google_cloud_netapp_v1::model::QuotaRule;
let x = UpdateQuotaRuleRequest::new().set_or_clear_quota_rule(Some(QuotaRule::default()/* use setters */));
let x = UpdateQuotaRuleRequest::new().set_or_clear_quota_rule(None::<QuotaRule>);Trait Implementations
Sourceimpl Clone for UpdateQuotaRuleRequest
impl Clone for UpdateQuotaRuleRequest
Sourcefn clone(&self) -> UpdateQuotaRuleRequest
fn clone(&self) -> UpdateQuotaRuleRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateQuotaRuleRequest
impl Debug for UpdateQuotaRuleRequest
Sourceimpl Default for UpdateQuotaRuleRequest
impl Default for UpdateQuotaRuleRequest
Sourcefn default() -> UpdateQuotaRuleRequest
fn default() -> UpdateQuotaRuleRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateQuotaRuleRequest
impl Message for UpdateQuotaRuleRequest
Sourceimpl PartialEq for UpdateQuotaRuleRequest
impl PartialEq for UpdateQuotaRuleRequest
impl StructuralPartialEq for UpdateQuotaRuleRequest