#[non_exhaustive]pub struct VerifyKmsConfigResponse {
pub healthy: bool,
pub health_error: String,
pub instructions: String,
/* private fields */
}Expand description
VerifyKmsConfigResponse contains the information if the config is correctly and error message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.healthy: boolOutput only. If the customer key configured correctly to the encrypt volume.
health_error: StringOutput only. Error message if config is not healthy.
instructions: StringOutput only. Instructions for the customers to provide the access to the encryption key.
Implementations
Sourceimpl VerifyKmsConfigResponse
impl VerifyKmsConfigResponse
Sourcepub fn set_healthy<T: Into<bool>>(self, v: T) -> Self
pub fn set_healthy<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_health_error<T: Into<String>>(self, v: T) -> Self
pub fn set_health_error<T: Into<String>>(self, v: T) -> Self
Sets the value of health_error.
Example
ⓘ
let x = VerifyKmsConfigResponse::new().set_health_error("example");Sourcepub fn set_instructions<T: Into<String>>(self, v: T) -> Self
pub fn set_instructions<T: Into<String>>(self, v: T) -> Self
Sets the value of instructions.
Example
ⓘ
let x = VerifyKmsConfigResponse::new().set_instructions("example");Trait Implementations
Sourceimpl Clone for VerifyKmsConfigResponse
impl Clone for VerifyKmsConfigResponse
Sourcefn clone(&self) -> VerifyKmsConfigResponse
fn clone(&self) -> VerifyKmsConfigResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifyKmsConfigResponse
impl Debug for VerifyKmsConfigResponse
Sourceimpl Default for VerifyKmsConfigResponse
impl Default for VerifyKmsConfigResponse
Sourcefn default() -> VerifyKmsConfigResponse
fn default() -> VerifyKmsConfigResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for VerifyKmsConfigResponse
impl Message for VerifyKmsConfigResponse
Sourceimpl PartialEq for VerifyKmsConfigResponse
impl PartialEq for VerifyKmsConfigResponse
impl StructuralPartialEq for VerifyKmsConfigResponse