#[non_exhaustive]pub enum CachePrePopulateState {
Unspecified,
NotNeeded,
InProgress,
Complete,
Error,
UnknownValue(UnknownValue),
}Expand description
State of the prepopulation job indicating how the prepopulation is progressing.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default unspecified state.
NotNeeded
State representing when the most recent create or update request did not require a prepopulation job.
InProgress
State representing when the most recent update request requested a prepopulation job but it has not yet completed.
Complete
State representing when the most recent update request requested a prepopulation job and it has completed successfully.
Error
State representing when the most recent update request requested a prepopulation job but the prepopulate job failed.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using CachePrePopulateState::value or CachePrePopulateState::name.
Implementations