BackupVault

Struct BackupVault 

#[non_exhaustive]
pub struct BackupVault {
Show 14 fields pub name: String, pub state: State, pub create_time: Option<Timestamp>, pub description: String, pub labels: HashMap<String, String>, pub backup_vault_type: BackupVaultType, pub source_region: String, pub backup_region: String, pub source_backup_vault: String, pub destination_backup_vault: String, pub backup_retention_policy: Option<BackupRetentionPolicy>, pub kms_config: String, pub encryption_state: EncryptionState, pub backups_crypto_key_version: String, /* private fields */
}
A NetApp BackupVault.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Identifier. The resource name of the backup vault. Format: projects/{project_id}/locations/{location}/backupVaults/{backup_vault_id}.

state: State

Output only. The backup vault state.

create_time: Option<Timestamp>

Output only. Create time of the backup vault.

description: String

Description of the backup vault.

labels: HashMap<String, String>

Resource labels to represent user provided metadata.

backup_vault_type: BackupVaultType

Optional. Type of backup vault to be created. Default is IN_REGION.

source_region: String

Output only. Region in which the backup vault is created. Format: projects/{project_id}/locations/{location}

backup_region: String

Optional. Region where the backups are stored. Format: projects/{project_id}/locations/{location}

source_backup_vault: String

Output only. Name of the Backup vault created in source region. Format: projects/{project_id}/locations/{location}/backupVaults/{backup_vault_id}

destination_backup_vault: String

Output only. Name of the Backup vault created in backup region. Format: projects/{project_id}/locations/{location}/backupVaults/{backup_vault_id}

backup_retention_policy: Option<BackupRetentionPolicy>

Optional. Backup retention policy defining the retention of backups.

kms_config: String

Optional. Specifies the Key Management System (KMS) configuration to be used for backup encryption. Format: projects/{project}/locations/{location}/kmsConfigs/{kms_config}

encryption_state: EncryptionState

Output only. Field indicating encryption state of CMEK backups.

backups_crypto_key_version: String

Output only. The crypto key version used to encrypt the backup vault. Format: projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}/cryptoKeyVersions/{crypto_key_version}

Implementations

Source

impl BackupVault

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = BackupVault::new().set_name("example");
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_netapp_v1::model::backup_vault::State;
let x0 = BackupVault::new().set_state(State::Creating);
let x1 = BackupVault::new().set_state(State::Ready);
let x2 = BackupVault::new().set_state(State::Deleting);
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = BackupVault::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = BackupVault::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = BackupVault::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = BackupVault::new().set_description("example");
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = BackupVault::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_backup_vault_type<T: Into<BackupVaultType>>(self, v: T) -> Self

Sets the value of backup_vault_type.

Example
use google_cloud_netapp_v1::model::backup_vault::BackupVaultType;
let x0 = BackupVault::new().set_backup_vault_type(BackupVaultType::InRegion);
let x1 = BackupVault::new().set_backup_vault_type(BackupVaultType::CrossRegion);
pub fn set_source_region<T: Into<String>>(self, v: T) -> Self

Sets the value of source_region.

Example
let x = BackupVault::new().set_source_region("example");
pub fn set_backup_region<T: Into<String>>(self, v: T) -> Self

Sets the value of backup_region.

Example
let x = BackupVault::new().set_backup_region("example");
pub fn set_source_backup_vault<T: Into<String>>(self, v: T) -> Self

Sets the value of source_backup_vault.

Example
let x = BackupVault::new().set_source_backup_vault("example");
pub fn set_destination_backup_vault<T: Into<String>>(self, v: T) -> Self

Sets the value of destination_backup_vault.

Example
let x = BackupVault::new().set_destination_backup_vault("example");
pub fn set_backup_retention_policy<T>(self, v: T) -> Self

Sets the value of backup_retention_policy.

Example
use google_cloud_netapp_v1::model::backup_vault::BackupRetentionPolicy;
let x = BackupVault::new().set_backup_retention_policy(BackupRetentionPolicy::default()/* use setters */);
pub fn set_or_clear_backup_retention_policy<T>(self, v: Option<T>) -> Self

Sets or clears the value of backup_retention_policy.

Example
use google_cloud_netapp_v1::model::backup_vault::BackupRetentionPolicy;
let x = BackupVault::new().set_or_clear_backup_retention_policy(Some(BackupRetentionPolicy::default()/* use setters */));
let x = BackupVault::new().set_or_clear_backup_retention_policy(None::<BackupRetentionPolicy>);
pub fn set_kms_config<T: Into<String>>(self, v: T) -> Self

Sets the value of kms_config.

Example
let x = BackupVault::new().set_kms_config("example");
pub fn set_encryption_state<T: Into<EncryptionState>>(self, v: T) -> Self

Sets the value of encryption_state.

Example
use google_cloud_netapp_v1::model::backup_vault::EncryptionState;
let x0 = BackupVault::new().set_encryption_state(EncryptionState::Pending);
let x1 = BackupVault::new().set_encryption_state(EncryptionState::Completed);
let x2 = BackupVault::new().set_encryption_state(EncryptionState::InProgress);
pub fn set_backups_crypto_key_version<T: Into<String>>(self, v: T) -> Self

Sets the value of backups_crypto_key_version.

Example
let x = BackupVault::new().set_backups_crypto_key_version("example");