CacheParameters

Struct CacheParameters 

#[non_exhaustive]
pub struct CacheParameters { pub peer_volume_name: String, pub peer_cluster_name: String, pub peer_svm_name: String, pub peer_ip_addresses: Vec<String>, pub enable_global_file_lock: Option<bool>, pub cache_config: Option<CacheConfig>, pub cache_state: CacheState, pub command: String, pub peering_command_expiry_time: Option<Timestamp>, pub passphrase: String, pub state_details: String, /* private fields */ }
Cache Parameters for the volume.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
peer_volume_name: String

Required. Name of the origin volume for the cache volume.

peer_cluster_name: String

Required. Name of the origin volume’s ONTAP cluster.

peer_svm_name: String

Required. Name of the origin volume’s SVM.

peer_ip_addresses: Vec<String>

Required. List of IC LIF addresses of the origin volume’s ONTAP cluster.

enable_global_file_lock: Option<bool>

Optional. Indicates whether the cache volume has global file lock enabled.

cache_config: Option<CacheConfig>

Optional. Configuration of the cache volume.

cache_state: CacheState

Output only. State of the cache volume indicating the peering status.

command: String

Output only. Copy-paste-able commands to be used on user’s ONTAP to accept peering requests.

peering_command_expiry_time: Option<Timestamp>

Optional. Expiration time for the peering command to be executed on user’s ONTAP.

passphrase: String

Output only. Temporary passphrase generated to accept cluster peering command.

state_details: String

Output only. Detailed description of the current cache state.

Implementations

Source

impl CacheParameters

pub fn new() -> Self

pub fn set_peer_volume_name<T: Into<String>>(self, v: T) -> Self

Sets the value of peer_volume_name.

Example
let x = CacheParameters::new().set_peer_volume_name("example");
pub fn set_peer_cluster_name<T: Into<String>>(self, v: T) -> Self

Sets the value of peer_cluster_name.

Example
let x = CacheParameters::new().set_peer_cluster_name("example");
pub fn set_peer_svm_name<T: Into<String>>(self, v: T) -> Self

Sets the value of peer_svm_name.

Example
let x = CacheParameters::new().set_peer_svm_name("example");
pub fn set_peer_ip_addresses<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of peer_ip_addresses.

Example
let x = CacheParameters::new().set_peer_ip_addresses(["a", "b", "c"]);
pub fn set_enable_global_file_lock<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of enable_global_file_lock.

Example
let x = CacheParameters::new().set_enable_global_file_lock(true);
pub fn set_or_clear_enable_global_file_lock<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of enable_global_file_lock.

Example
let x = CacheParameters::new().set_or_clear_enable_global_file_lock(Some(false));
let x = CacheParameters::new().set_or_clear_enable_global_file_lock(None::<bool>);
pub fn set_cache_config<T>(self, v: T) -> Self
where T: Into<CacheConfig>,

Sets the value of cache_config.

Example
use google_cloud_netapp_v1::model::CacheConfig;
let x = CacheParameters::new().set_cache_config(CacheConfig::default()/* use setters */);
pub fn set_or_clear_cache_config<T>(self, v: Option<T>) -> Self
where T: Into<CacheConfig>,

Sets or clears the value of cache_config.

Example
use google_cloud_netapp_v1::model::CacheConfig;
let x = CacheParameters::new().set_or_clear_cache_config(Some(CacheConfig::default()/* use setters */));
let x = CacheParameters::new().set_or_clear_cache_config(None::<CacheConfig>);
pub fn set_cache_state<T: Into<CacheState>>(self, v: T) -> Self

Sets the value of cache_state.

Example
use google_cloud_netapp_v1::model::cache_parameters::CacheState;
let x0 = CacheParameters::new().set_cache_state(CacheState::PendingClusterPeering);
let x1 = CacheParameters::new().set_cache_state(CacheState::PendingSvmPeering);
let x2 = CacheParameters::new().set_cache_state(CacheState::Peered);
pub fn set_command<T: Into<String>>(self, v: T) -> Self

Sets the value of command.

Example
let x = CacheParameters::new().set_command("example");
pub fn set_peering_command_expiry_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of peering_command_expiry_time.

Example
use wkt::Timestamp;
let x = CacheParameters::new().set_peering_command_expiry_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_peering_command_expiry_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of peering_command_expiry_time.

Example
use wkt::Timestamp;
let x = CacheParameters::new().set_or_clear_peering_command_expiry_time(Some(Timestamp::default()/* use setters */));
let x = CacheParameters::new().set_or_clear_peering_command_expiry_time(None::<Timestamp>);
pub fn set_passphrase<T: Into<String>>(self, v: T) -> Self

Sets the value of passphrase.

Example
let x = CacheParameters::new().set_passphrase("example");
pub fn set_state_details<T: Into<String>>(self, v: T) -> Self

Sets the value of state_details.

Example
let x = CacheParameters::new().set_state_details("example");