#[non_exhaustive]pub struct HostGroup {
pub name: String,
pub type: Type,
pub state: State,
pub create_time: Option<Timestamp>,
pub hosts: Vec<String>,
pub os_type: OsType,
pub description: String,
pub labels: HashMap<String, String>,
/* private fields */
}Expand description
Host group is a collection of hosts that can be used for accessing a Block Volume.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the host group.
Format:
projects/{project_number}/locations/{location_id}/hostGroups/{host_group_id}.
type: TypeRequired. Type of the host group.
state: StateOutput only. State of the host group.
create_time: Option<Timestamp>Output only. Create time of the host group.
hosts: Vec<String>Required. The list of hosts associated with the host group.
os_type: OsTypeRequired. The OS type of the host group. It indicates the type of operating system used by all of the hosts in the HostGroup. All hosts in a HostGroup must be of the same OS type. This can be set only when creating a HostGroup.
description: StringOptional. Description of the host group.
labels: HashMap<String, String>Optional. Labels of the host group.
Implementations
Sourceimpl HostGroup
impl HostGroup
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = HostGroup::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = HostGroup::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = HostGroup::new().set_or_clear_create_time(None::<Timestamp>);