HybridReplicationParameters

Struct HybridReplicationParameters 

#[non_exhaustive]
pub struct HybridReplicationParameters { pub replication: String, pub peer_volume_name: String, pub peer_cluster_name: String, pub peer_svm_name: String, pub peer_ip_addresses: Vec<String>, pub cluster_location: String, pub description: String, pub labels: HashMap<String, String>, pub replication_schedule: HybridReplicationSchedule, pub hybrid_replication_type: VolumeHybridReplicationType, pub large_volume_constituent_count: i32, /* private fields */ }
The Hybrid Replication parameters for the volume.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
replication: String

Required. Desired name for the replication of this volume.

peer_volume_name: String

Required. Name of the user’s local source volume to be peered with the destination volume.

peer_cluster_name: String

Required. Name of the user’s local source cluster to be peered with the destination cluster.

peer_svm_name: String

Required. Name of the user’s local source vserver svm to be peered with the destination vserver svm.

peer_ip_addresses: Vec<String>

Required. List of node ip addresses to be peered with.

cluster_location: String

Optional. Name of source cluster location associated with the Hybrid replication. This is a free-form field for the display purpose only.

description: String

Optional. Description of the replication.

labels: HashMap<String, String>

Optional. Labels to be added to the replication as the key value pairs.

replication_schedule: HybridReplicationSchedule

Optional. Replication Schedule for the replication created.

hybrid_replication_type: VolumeHybridReplicationType

Optional. Type of the hybrid replication.

large_volume_constituent_count: i32

Optional. Constituent volume count for large volume.

Implementations

Source

impl HybridReplicationParameters

pub fn new() -> Self

Creates a new default instance.

pub fn set_replication<T: Into<String>>(self, v: T) -> Self

Sets the value of replication.

Example
let x = HybridReplicationParameters::new().set_replication("example");
pub fn set_peer_volume_name<T: Into<String>>(self, v: T) -> Self

Sets the value of peer_volume_name.

Example
let x = HybridReplicationParameters::new().set_peer_volume_name("example");
pub fn set_peer_cluster_name<T: Into<String>>(self, v: T) -> Self

Sets the value of peer_cluster_name.

Example
let x = HybridReplicationParameters::new().set_peer_cluster_name("example");
pub fn set_peer_svm_name<T: Into<String>>(self, v: T) -> Self

Sets the value of peer_svm_name.

Example
let x = HybridReplicationParameters::new().set_peer_svm_name("example");
pub fn set_peer_ip_addresses<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of peer_ip_addresses.

Example
let x = HybridReplicationParameters::new().set_peer_ip_addresses(["a", "b", "c"]);
pub fn set_cluster_location<T: Into<String>>(self, v: T) -> Self

Sets the value of cluster_location.

Example
let x = HybridReplicationParameters::new().set_cluster_location("example");
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = HybridReplicationParameters::new().set_description("example");
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = HybridReplicationParameters::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_replication_schedule<T: Into<HybridReplicationSchedule>>( self, v: T, ) -> Self

Sets the value of replication_schedule.

Example
use google_cloud_netapp_v1::model::HybridReplicationSchedule;
let x0 = HybridReplicationParameters::new().set_replication_schedule(HybridReplicationSchedule::Every10Minutes);
let x1 = HybridReplicationParameters::new().set_replication_schedule(HybridReplicationSchedule::Hourly);
let x2 = HybridReplicationParameters::new().set_replication_schedule(HybridReplicationSchedule::Daily);
pub fn set_hybrid_replication_type<T: Into<VolumeHybridReplicationType>>( self, v: T, ) -> Self

Sets the value of hybrid_replication_type.

Example
use google_cloud_netapp_v1::model::hybrid_replication_parameters::VolumeHybridReplicationType;
let x0 = HybridReplicationParameters::new().set_hybrid_replication_type(VolumeHybridReplicationType::Migration);
let x1 = HybridReplicationParameters::new().set_hybrid_replication_type(VolumeHybridReplicationType::ContinuousReplication);
let x2 = HybridReplicationParameters::new().set_hybrid_replication_type(VolumeHybridReplicationType::OnpremReplication);
pub fn set_large_volume_constituent_count<T: Into<i32>>(self, v: T) -> Self

Sets the value of large_volume_constituent_count.

Example
let x = HybridReplicationParameters::new().set_large_volume_constituent_count(42);