#[non_exhaustive]pub struct HybridReplicationParameters {
pub replication: String,
pub peer_volume_name: String,
pub peer_cluster_name: String,
pub peer_svm_name: String,
pub peer_ip_addresses: Vec<String>,
pub cluster_location: String,
pub description: String,
pub labels: HashMap<String, String>,
pub replication_schedule: HybridReplicationSchedule,
pub hybrid_replication_type: VolumeHybridReplicationType,
pub large_volume_constituent_count: i32,
/* private fields */
}Expand description
The Hybrid Replication parameters for the volume.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.replication: StringRequired. Desired name for the replication of this volume.
peer_volume_name: StringRequired. Name of the user’s local source volume to be peered with the destination volume.
peer_cluster_name: StringRequired. Name of the user’s local source cluster to be peered with the destination cluster.
peer_svm_name: StringRequired. Name of the user’s local source vserver svm to be peered with the destination vserver svm.
peer_ip_addresses: Vec<String>Required. List of node ip addresses to be peered with.
cluster_location: StringOptional. Name of source cluster location associated with the Hybrid replication. This is a free-form field for the display purpose only.
description: StringOptional. Description of the replication.
labels: HashMap<String, String>Optional. Labels to be added to the replication as the key value pairs.
replication_schedule: HybridReplicationScheduleOptional. Replication Schedule for the replication created.
hybrid_replication_type: VolumeHybridReplicationTypeOptional. Type of the hybrid replication.
large_volume_constituent_count: i32Optional. Constituent volume count for large volume.
Implementations
Sourceimpl HybridReplicationParameters
impl HybridReplicationParameters
Sourcepub fn set_replication<T: Into<String>>(self, v: T) -> Self
pub fn set_replication<T: Into<String>>(self, v: T) -> Self
Sets the value of replication.
Example
let x = HybridReplicationParameters::new().set_replication("example");Sourcepub fn set_peer_volume_name<T: Into<String>>(self, v: T) -> Self
pub fn set_peer_volume_name<T: Into<String>>(self, v: T) -> Self
Sets the value of peer_volume_name.
Example
let x = HybridReplicationParameters::new().set_peer_volume_name("example");Sourcepub fn set_peer_cluster_name<T: Into<String>>(self, v: T) -> Self
pub fn set_peer_cluster_name<T: Into<String>>(self, v: T) -> Self
Sets the value of peer_cluster_name.
Example
let x = HybridReplicationParameters::new().set_peer_cluster_name("example");Sourcepub fn set_peer_svm_name<T: Into<String>>(self, v: T) -> Self
pub fn set_peer_svm_name<T: Into<String>>(self, v: T) -> Self
Sets the value of peer_svm_name.
Example
let x = HybridReplicationParameters::new().set_peer_svm_name("example");Sourcepub fn set_peer_ip_addresses<T, V>(self, v: T) -> Self
pub fn set_peer_ip_addresses<T, V>(self, v: T) -> Self
Sets the value of peer_ip_addresses.
Example
let x = HybridReplicationParameters::new().set_peer_ip_addresses(["a", "b", "c"]);Sourcepub fn set_cluster_location<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster_location<T: Into<String>>(self, v: T) -> Self
Sets the value of cluster_location.
Example
let x = HybridReplicationParameters::new().set_cluster_location("example");Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = HybridReplicationParameters::new().set_description("example");Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_replication_schedule<T: Into<HybridReplicationSchedule>>(
self,
v: T,
) -> Self
pub fn set_replication_schedule<T: Into<HybridReplicationSchedule>>( self, v: T, ) -> Self
Sets the value of replication_schedule.
Example
use google_cloud_netapp_v1::model::HybridReplicationSchedule;
let x0 = HybridReplicationParameters::new().set_replication_schedule(HybridReplicationSchedule::Every10Minutes);
let x1 = HybridReplicationParameters::new().set_replication_schedule(HybridReplicationSchedule::Hourly);
let x2 = HybridReplicationParameters::new().set_replication_schedule(HybridReplicationSchedule::Daily);Sourcepub fn set_hybrid_replication_type<T: Into<VolumeHybridReplicationType>>(
self,
v: T,
) -> Self
pub fn set_hybrid_replication_type<T: Into<VolumeHybridReplicationType>>( self, v: T, ) -> Self
Sets the value of hybrid_replication_type.
Example
use google_cloud_netapp_v1::model::hybrid_replication_parameters::VolumeHybridReplicationType;
let x0 = HybridReplicationParameters::new().set_hybrid_replication_type(VolumeHybridReplicationType::Migration);
let x1 = HybridReplicationParameters::new().set_hybrid_replication_type(VolumeHybridReplicationType::ContinuousReplication);
let x2 = HybridReplicationParameters::new().set_hybrid_replication_type(VolumeHybridReplicationType::OnpremReplication);Sourcepub fn set_large_volume_constituent_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_large_volume_constituent_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of large_volume_constituent_count.
Example
let x = HybridReplicationParameters::new().set_large_volume_constituent_count(42);Trait Implementations
Sourceimpl Clone for HybridReplicationParameters
impl Clone for HybridReplicationParameters
Sourcefn clone(&self) -> HybridReplicationParameters
fn clone(&self) -> HybridReplicationParameters
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more