#[non_exhaustive]pub enum State {
Unspecified,
Ready,
Creating,
Deleting,
Updating,
Restoring,
Disabled,
Error,
Preparing,
ReadOnly,
UnknownValue(UnknownValue),
}Expand description
The volume states
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified Volume State
Ready
Volume State is Ready
Creating
Volume State is Creating
Deleting
Volume State is Deleting
Updating
Volume State is Updating
Restoring
Volume State is Restoring
Disabled
Volume State is Disabled
Error
Volume State is Error
Preparing
Volume State is Preparing. Note that this is different from CREATING where CREATING means the volume is being created, while PREPARING means the volume is created and now being prepared for the replication.
ReadOnly
Volume State is Read Only
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations